@@ -83,9 +83,6 @@ class Input(object):
         self.fulfillment = fulfillment
         self.fulfills = fulfills
         self.owners_before = owners_before
-        
-        self.app_key = None
-        self.app_id = None
 
     def __eq__(self, other):
         # TODO: If `other !== Fulfillment` return `False`
@@ -1086,7 +1083,7 @@ class Transaction(object):
             'metadata': self.metadata,
             'asset': self.asset,
             'version': self.version,
-            'id': self._id
+            'id': self._id,
         }
 
     @staticmethod
@@ -1206,12 +1203,7 @@ class Transaction(object):
         """
         operation = tx.get('operation', Transaction.CREATE) if isinstance(tx, dict) else Transaction.CREATE
         cls = Transaction.resolve_class(operation)
-        try:
-            tx.pop("app_key")
-            tx.pop("app_id")
-        except KeyError:
-            pass
-        
+
         if not skip_schema_validation:
             cls.validate_id(tx)
             cls.validate_schema(tx)
