@@ -85,8 +85,6 @@ class TransactionListApi(Resource):
 
         try:
             tx_obj = Transaction.from_dict(tx)
-            tx_obj.app_key = app_key
-            tx_obj.app_id = app_id
             
         except SchemaValidationError as e:
             return make_error(
